==> nextcloud-24.0.9.tgz: nextcloud/apps/privacy/l10n/fi.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Tietosuoja",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Tämä tietosuojakeskus näyttää missä tietosi sijaitsevat ja kenellä on pääsy tietoihisi. Pääsy voi olla mahdollinen koska olet jakanut tietojasi muiden kanssa tai ylläpitäjällä on pääsy tiedostoihisi.",
    "Remove external admin" : "Poista ulkoinen ylläpitäjä",
    "Add external admin" : "Lisää ulkoinen ylläpitäjä",
    "Name of external admin" : "Ulkoisen järjestelmänvalvojan nimi",
    "This server is using full-disk-encryption." : "Tämä palvelin käyttää täyttä levyn salausta.",
    "Additionally, this server is protected with full-disk-encryption." : "Lisäksi tämä palvelin on suojattu täydellä levyn salauksella.",
    "This server is protected with full-disk-encryption." : "Tämä palvelin on suojattu täydellä levyn salauksella.",
    "Your files are not protected by encryption." : "Tiedostojasi ei ole suojattu salauksella.",
    "Your data is located in:" : "Tietojesi sijainti on:",
    "The admin has not selected the location of the server yet." : "Ylläpitäjä ei ole vielä valinnut palvelimen sijaintia.",
    "Change data location" : "Vaihda tietojen sijainti",
    "Please select a region" : "Valitse alue",
    "You don't have any shares with individual users." : "Sinulla ei ole jakoja yksittäisten käyttäjien kanssa.",
    "Somaliland" : "Somalimaa",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Yhdistyneet arabiemiirikunnat",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua ja Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Etelämanner",
    "Argentina" : "Argentiina",
    "American Samoa" : "Amerikan Samoa",
    "Austria" : "Itävalta",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ahvenanmaa",
    "Azerbaijan" : "Azerbaidžan",
    "Bosnia and Herzegovina" : "Bosnia ja Hertsegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgia",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius ja Saba",
    "Brazil" : "Brasilia",
    "Bahamas" : "Bahamasaaret",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet'nsaari",
    "Botswana" : "Botswana",
    "Belarus" : "Valko-Venäjä",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kookossaaret",
    "Democratic Republic of the Congo" : "Kongon demokraattinen tasavalta",
    "Central African Republic" : "Keski-Afrikan tasavalta",
    "Congo" : "Kongo",
    "Switzerland" : "Sveitsi",
    "Cote d'Ivoire" : "Norsunluurannikko",
    "Cook Islands" : "Cookinsaaret",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Kiina",
    "Colombia" : "Kolumbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuuba",
    "Cabo Verde" : "Kap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Joulusaari",
    "Cyprus" : "Kypros",
    "Czech" : "Tšekki",
    "Germany" : "Saksa",
    "Djibouti" : "Djibouti",
    "Denmark" : "Tanska",
    "Dominican Republic" : "Dominikaaninen tasavalta",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Viro",
    "Egypt" : "Egypti",
    "West Sahara" : "Länsi-Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Espanja",
    "Ethiopia" : "Etiopia",
    "Finland" : "Suomi",
    "Fiji" : "Fidži",
    "Falkland Islands" : "Falklandinsaaret",
    "Micronesia" : "Mikronesia",
    "Faroe Islands" : "Färsaaret",
    "France" : "Ranska",
    "Gabon" : "Gabon",
    "United Kingdom" : "Yhdistynyt kuningaskunta",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Ranskan Guayana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grönlanti",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Päiväntasaajan Guinea",
    "Greece" : "Kreikka",
    "South Georgia and the South Sandwich Islands" : "Etelä-Georgia ja Eteläiset Sandwichsaaret",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard ja McDonaldinsaaret",
    "Croatia" : "Kroatia",
    "Haiti" : "Haiti",
    "Hungary" : "Unkari",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanti",
    "Israel" : "Israel",
    "Isle of Man" : "Mansaari",
    "India" : "Intia",
    "British Indian Ocean Territory" : "Brittiläinen Intian valtameren alue",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Islanti",
    "Italy" : "Italia",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordan",
    "Japan" : "Japani",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgisia",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comores" : "Komorit",
    "Saint Kitts and Nevis" : "Saint Kitts ja Nevis",
    "North Korea" : "Pohjois-Korea",
    "South Korea" : "Etelä-Korea",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Caymansaaret",
    "Kazakhstan" : "Kazakhstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Liettua",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Moldova" : "Moldova",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Marshallinsaaret",
    "Macedonia" : "Makedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Pohjois-Mariaanit",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Malediivit",
    "Malawi" : "Malawi",
    "Mexico" : "Meksiko",
    "Malaysia" : "Malesia",
    "Mozambique" : "Mosambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Uusi-Kaledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkinsaari",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Alankomaat",
    "Norway" : "Norja",
    "Nepal" : "Nepali",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Uusi-Seelanti",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Ranskan Polynesia",
    "Papua New Guinea" : "Papua-Uusi-Guinea",
    "Philippines" : "Filippiinit",
    "Pakistan" : "Pakistan",
    "Poland" : "Puola",
    "Saint Pierre and Miquelon" : "Saint Pierre ja Miquelon",
    "Pitcairn" : "Pitcairnsaaret",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palestiina",
    "Portugal" : "Portugali",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russia" : "Venäjä",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudi-Arabia",
    "Solomon Islands" : "Salomonsaaret",
    "Seychelles" : "Seychellit",
    "Sudan" : "Sudan",
    "Sweden" : "Ruotsi",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension ja Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Huippuvuoret ja Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Etelä-Sudan",
    "Sao Tome and Principe" : "São Tomé ja Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Syyria",
    "Swaziland" : "Swazimaa",
    "Turks and Caicos Islands" : "Turks- ja Caicossaaret",
    "Chad" : "Tšad",
    "Fr. S. Antarctic Lands" : "Ranskan eteläiset ja antarktiset alueet",
    "Togo" : "Togo",
    "Thailand" : "Thaimaa",
    "Tajikistan" : "Tadžikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Itä-Timor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turkki",
    "Trinidad and Tobago" : "Trinidad ja Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tansania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Yhdysvaltojen pienet syrjäiset saaret",
    "United States" : "Yhdysvallat",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Saint Vincent and the Grenadines" : "Saint Vincent ja Grenadiinit",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Brittiläiset Neitsytsaaret",
    "Virgin Islands (U.S.)" : "Yhdysvaltain Neitsytsaaret",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis ja Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Etelä-Afrikka",
    "Zambia" : "Sambia",
    "Zimbabwe" : "Zimbabwe",
    "Your %s account" : "Sinun %s-tili",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Tietosi edustavat sinua ja niitä on mahdollista väärinkäyttää. Me Nextcloud-kehittäjät uskomme, että sinulle on oikeus päättää, mitä tiedoillesi tapahtuu. Nextcloud suojaa oikeuksiasi kuten Käyttäjätietojen julistus ne määrittää.",
    "User Data Manifesto 2.0" : "Käyttäjätietojen julistus 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Perusoikeuksien määrittäminen henkilökohtaisten tietojen hallinnoimiseksi internetaikakaudella",
    "Control" : "Hallinta",
    "over user data access" : "käyttäjien tietoihin pääsyyn",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Käyttäjän yksiselitteisesti ja omasta tahdostaan lähettämien tietojen tulee olla käyttäjän täydessä hallinnassa. Käyttäjien tulee pystyä päättää, kenelle tietoihin annetaan suora pääsy ja millä oikeuksin sekä lisenssein.",
    "Knowledge" : "Tietoisuus",
    "of how the data is stored" : "kuinka tiedot tallennetaan",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Kun tietoja lähetetään yksittäiselle palveluntarjoajalle, käyttäjille tulee ilmoittaa missä kyseinen palveluntarjoaja säilyttää tiedot, kuinka pitkään tiedot säilytetään, millä lainsäädäntöalueella palveluntarjoaja toimii ja mitkä lait vaikuttavat toimintaan.",
    "Freedom" : "Vapaus",
    "to choose a platform" : "valita alusta",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Käyttäjien tulee aina pystyä siirtämään tiedot pois palvelusta milloin tahansa ilman minkäänlaista toimittajakohtaista sidonnaisuutta. Avoimet standardit tiedostomuodoille ja protokollille ovat välttämättömiä tämän vuoksi.",
    "Learn more ↗" : "Lue lisää ↗",
    "Where is your data?" : "Missä tietosi ovat?",
    "Who has access to your data?" : "Kenellä on pääsy tietoihisi?",
    "Administrators" : "Ylläpitäjät",
    "People you shared with" : "Ihmiset joiden kanssa jaoit tiedot",
    "Privacy policy" : "Tietosuojakäytäntö",
    "Read the privacy policy." : "Lue tietosuojakäytäntö.",
    "Encryption" : "Salaus"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.5.tgz: nextcloud/apps/privacy/l10n/fi.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Tietosuoja",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Tämä tietosuojakeskus näyttää missä tietosi sijaitsevat ja kenellä on pääsy tietoihisi. Pääsy voi olla mahdollinen koska olet jakanut tietojasi muiden kanssa tai ylläpitäjällä on pääsy tiedostoihisi.",
    "Administrators" : "Ylläpitäjät",
    "Add external admin" : "Lisää ulkoinen ylläpitäjä",
    "Add" : "Lisää",
    "Name of external admin" : "Ulkoisen järjestelmänvalvojan nimi",
    "Encryption" : "Salaus",
    "This server is using full-disk-encryption." : "Tämä palvelin käyttää täyttä levyn salausta.",
    "Additionally, this server is protected with full-disk-encryption." : "Lisäksi tämä palvelin on suojattu täydellä levyn salauksella.",
    "This server is protected with full-disk-encryption." : "Tämä palvelin on suojattu täydellä levyn salauksella.",
    "Your files are not protected by encryption." : "Tiedostojasi ei ole suojattu salauksella.",
    "Privacy policy" : "Tietosuojakäytäntö",
    "Who has access to your data?" : "Kenellä on pääsy tietoihisi?",
    "Where is your data?" : "Missä tietosi ovat?",
    "Your data is located in:" : "Tietojesi sijainti on:",
    "Change data location" : "Vaihda tietojen sijainti",
    "Region" : "Alue",
    "Please select a region" : "Valitse alue",
    "User Data Manifesto 2.0" : "Käyttäjätietojen julistus 2.0",
    "Control" : "Hallinta",
    "over user data access" : "käyttäjien tietoihin pääsyyn",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Käyttäjän yksiselitteisesti ja omasta tahdostaan lähettämien tietojen tulee olla käyttäjän täydessä hallinnassa. Käyttäjien tulee pystyä päättää, kenelle tietoihin annetaan suora pääsy ja millä oikeuksin sekä lisenssein.",
    "Knowledge" : "Tietoisuus",
    "of how the data is stored" : "kuinka tiedot tallennetaan",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Kun tietoja lähetetään yksittäiselle palveluntarjoajalle, käyttäjille tulee ilmoittaa missä kyseinen palveluntarjoaja säilyttää tiedot, kuinka pitkään tiedot säilytetään, millä lainsäädäntöalueella palveluntarjoaja toimii ja mitkä lait vaikuttavat toimintaan.",
    "Freedom" : "Vapaus",
    "to choose a platform" : "valita alusta",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Käyttäjien tulee aina pystyä siirtämään tiedot pois palvelusta milloin tahansa ilman minkäänlaista toimittajakohtaista sidonnaisuutta. Avoimet standardit tiedostomuodoille ja protokollille ovat välttämättömiä tämän vuoksi.",
    "Learn more ↗" : "Lue lisää ↗",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Tietosi edustavat sinua ja niitä on mahdollista väärinkäyttää. Me Nextcloud-kehittäjät uskomme, että sinulle on oikeus päättää, mitä tiedoillesi tapahtuu. Nextcloud suojaa oikeuksiasi kuten Käyttäjätietojen julistus ne määrittää.",
    "Somaliland" : "Somalimaa",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Yhdistyneet arabiemiirikunnat",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua ja Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Etelämanner",
    "Argentina" : "Argentiina",
    "American Samoa" : "Amerikan Samoa",
    "Austria" : "Itävalta",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ahvenanmaa",
    "Azerbaijan" : "Azerbaidžan",
    "Bosnia and Herzegovina" : "Bosnia ja Hertsegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgia",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius ja Saba",
    "Brazil" : "Brasilia",
    "Bahamas" : "Bahamasaaret",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet'nsaari",
    "Botswana" : "Botswana",
    "Belarus" : "Valko-Venäjä",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kookossaaret",
    "Democratic Republic of the Congo" : "Kongon demokraattinen tasavalta",
    "Central African Republic" : "Keski-Afrikan tasavalta",
    "Congo" : "Kongo",
    "Switzerland" : "Sveitsi",
    "Cote d'Ivoire" : "Norsunluurannikko",
    "Cook Islands" : "Cookinsaaret",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Kiina",
    "Colombia" : "Kolumbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuuba",
    "Cabo Verde" : "Kap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Joulusaari",
    "Cyprus" : "Kypros",
    "Czech" : "Tšekki",
    "Germany" : "Saksa",
    "Djibouti" : "Djibouti",
    "Denmark" : "Tanska",
    "Dominican Republic" : "Dominikaaninen tasavalta",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Viro",
    "Egypt" : "Egypti",
    "West Sahara" : "Länsi-Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Espanja",
    "Ethiopia" : "Etiopia",
    "Finland" : "Suomi",
    "Fiji" : "Fidži",
    "Falkland Islands" : "Falklandinsaaret",
    "Micronesia" : "Mikronesia",
    "Faroe Islands" : "Färsaaret",
    "France" : "Ranska",
    "Gabon" : "Gabon",
    "United Kingdom" : "Yhdistynyt kuningaskunta",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Ranskan Guayana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grönlanti",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Päiväntasaajan Guinea",
    "Greece" : "Kreikka",
    "South Georgia and the South Sandwich Islands" : "Etelä-Georgia ja Eteläiset Sandwichsaaret",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard ja McDonaldinsaaret",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatia",
    "Haiti" : "Haiti",
    "Hungary" : "Unkari",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanti",
    "Israel" : "Israel",
    "Isle of Man" : "Mansaari",
    "India" : "Intia",
    "British Indian Ocean Territory" : "Brittiläinen Intian valtameren alue",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Islanti",
    "Italy" : "Italia",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordan",
    "Japan" : "Japani",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgisia",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comores" : "Komorit",
    "Saint Kitts and Nevis" : "Saint Kitts ja Nevis",
    "North Korea" : "Pohjois-Korea",
    "South Korea" : "Etelä-Korea",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Caymansaaret",
    "Kazakhstan" : "Kazakhstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Liettua",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Moldova" : "Moldova",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Marshallinsaaret",
    "Macedonia" : "Makedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Pohjois-Mariaanit",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Malediivit",
    "Malawi" : "Malawi",
    "Mexico" : "Meksiko",
    "Malaysia" : "Malesia",
    "Mozambique" : "Mosambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Uusi-Kaledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkinsaari",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Alankomaat",
    "Norway" : "Norja",
    "Nepal" : "Nepali",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Uusi-Seelanti",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Ranskan Polynesia",
    "Papua New Guinea" : "Papua-Uusi-Guinea",
    "Philippines" : "Filippiinit",
    "Pakistan" : "Pakistan",
    "Poland" : "Puola",
    "Saint Pierre and Miquelon" : "Saint Pierre ja Miquelon",
    "Pitcairn" : "Pitcairnsaaret",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palestiina",
    "Portugal" : "Portugali",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russia" : "Venäjä",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudi-Arabia",
    "Solomon Islands" : "Salomonsaaret",
    "Seychelles" : "Seychellit",
    "Sudan" : "Sudan",
    "Sweden" : "Ruotsi",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension ja Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Huippuvuoret ja Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Etelä-Sudan",
    "Sao Tome and Principe" : "São Tomé ja Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Syyria",
    "Swaziland" : "Swazimaa",
    "Turks and Caicos Islands" : "Turks- ja Caicossaaret",
    "Chad" : "Tšad",
    "Fr. S. Antarctic Lands" : "Ranskan eteläiset ja antarktiset alueet",
    "Togo" : "Togo",
    "Thailand" : "Thaimaa",
    "Tajikistan" : "Tadžikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Itä-Timor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turkki",
    "Trinidad and Tobago" : "Trinidad ja Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tansania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Yhdysvaltojen pienet syrjäiset saaret",
    "United States" : "Yhdysvallat",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Saint Vincent and the Grenadines" : "Saint Vincent ja Grenadiinit",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Brittiläiset Neitsytsaaret",
    "Virgin Islands (U.S.)" : "Yhdysvaltain Neitsytsaaret",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis ja Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Etelä-Afrikka",
    "Zambia" : "Sambia",
    "Zimbabwe" : "Zimbabwe",
    "The admin has not selected the location of the server yet." : "Ylläpitäjä ei ole vielä valinnut palvelimen sijaintia.",
    "You don't have any shares with individual users." : "Sinulla ei ole jakoja yksittäisten käyttäjien kanssa.",
    "Your %s account" : "Sinun %s-tili",
    "Defining basic rights for people to control their own data in the internet age" : "Perusoikeuksien määrittäminen henkilökohtaisten tietojen hallinnoimiseksi internetaikakaudella",
    "People you shared with" : "Ihmiset joiden kanssa jaoit tiedot",
    "Read the privacy policy." : "Lue tietosuojakäytäntö."
},
"nplurals=2; plural=(n != 1);");
